==> scholarsync-0.0.3.0.tar.gz: scholarsync-0.0.3.0/README.md <==
# Combined Data Mining Utility

This script provides a combined utility for data mining tasks related to PubMed articles. It offers various functionalities to facilitate tasks such as searching PubMed, retrieving abstracts, downloading full texts, processing PubMed IDs, crawling URLs, removing duplicates, converting PDFs to text files, and additional utilities.

## Getting Started

### Prerequisites

Ensure you have Python installed on your system. The script is compatible with both Python 2 and 3.

### Installation

1. pip install scholarsync
	

To address the error message,
	WARNING: The script scholarsync is installed in '/home/username/.local/bin' which is not on PATH.
	 open a terminal and type the following command, then press Enter:

.. code-block:: bash

   echo 'export PATH="$PATH:/home/username/.local/bin"' >> ~/.bashrc && source ~/.bashrc

Replace ``username`` with your actual username.




## Usage

Upon running the script, you will be prompted with a menu to select the desired functionality. The available options include:

- PubMed search/query
- Get abstracts from PubMed IDs
- Attempt full text download from PubMed
- Process PubMed IDs to get DOI for 3rd party search
- URL transformation of PubMed IDs for 3rd party search
- Crawling and downloading from URLs
- Removing duplicates
- Converting PDFs to text files
- Additional utilities

Follow the on-screen instructions to navigate through the menu and execute the desired tasks.

## License

By using this script, you agree to the terms of the LICENSE included in the repository.

## Contributing

Contributions are welcome! Feel free to submit pull requests or open issues for any improvements or bug fixes.

## Acknowledgments

- This script was developed to simplify various data mining tasks related to PubMed articles.
- Special thanks to the developers and contributors of the libraries used in this script.

==> scholarsync-0.0.3.84.tar.gz: scholarsync-0.0.3.84/README.md <==
# Combined Data Mining Utility

This script provides a combined utility for data mining tasks related to PubMed articles. It offers various functionalities to facilitate tasks such as searching PubMed, retrieving abstracts, downloading full texts, processing PubMed IDs, crawling URLs, removing duplicates, converting PDFs to text files, and additional utilities.

## Getting Started

### Prerequisites

Ensure you have Python installed on your system. The script is compatible with both Python 2 and 3.

### Installation

1. Install the required package:

    ```bash
    pip install scholarsync
    ```

2. If you encounter the following warning message:

    ```
    WARNING: The script scholarsync is installed in '/home/username/.local/bin' which is not on PATH.
    ```

    Open a terminal and type the following command, then press Enter:

    ```bash
    echo 'export PATH="$PATH:/home/username/.local/bin"' >> ~/.bashrc && source ~/.bashrc
    ```

    Replace `username` with your actual username.

## Usage

Upon running the script, you will be prompted with a menu to select the desired functionality. The available options include:

- PubMed search/query
- Get abstracts from PubMed IDs
- Attempt full text download from PubMed
- Process PubMed IDs to get DOI 
- URL transformation of PubMed IDs 
- Crawling and downloading from URLs
- Removing duplicates
- Converting PDFs to text files
- Additional utilities

Follow the on-screen instructions to navigate through the menu and execute the desired tasks.

## License

By using this script, you agree to the terms of the LICENSE included in the repository.

## Contributing

Contributions are welcome! Feel free to submit pull requests or open issues for any improvements or bug fixes.

## Acknowledgments

- This script was developed to simplify various data mining tasks related to PubMed articles.
- Special thanks to the developers and contributors of the libraries used in this script.
